summaryrefslogtreecommitdiff
path: root/staging
diff options
context:
space:
mode:
Diffstat (limited to 'staging')
-rw-r--r--staging/cli.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/staging/cli.c b/staging/cli.c
index 7d8e2ce..9abc648 100644
--- a/staging/cli.c
+++ b/staging/cli.c
@@ -27,13 +27,13 @@ void mz_cli_init()
{
amp_head = automops_init();
// Initialize default credentials (will be overwritten by mausezahn.cfg)
strcpy(mz_username, MZ_DEFAULT_USERNAME);
strcpy(mz_password, MZ_DEFAULT_PASSWORD);
strcpy(mz_enable, MZ_DEFAULT_ENABLE_PASSWORD);
// read login credentials from config file
- if (cli_read_cfg("mausezahn.cfg")) {
+ if (cli_read_cfg("mausezahn.conf")) {
fprintf(stderr, "mz: Problems opening config file. Will use defaults\n");
}
@@ -27,13 +27,13 @@ void mz_cli_init()
{
amp_head = automops_init();
- // Initialize default credentials (will be overwritten by mausezahn.cfg)
+ // Initialize default credentials (will be overwritten by mausezahn.conf)
strcpy(mz_username, MZ_DEFAULT_USERNAME);
strcpy(mz_password, MZ_DEFAULT_PASSWORD);